@@ -26,7 +26,6 @@ from typing import Any
 from typing import List
 from typing import Tuple
 from typing import Dict
-from typing import Callable
 from enum import Enum, Flag
 # pylint: disable=wrong-import-position
 import sys
@@ -53,13 +52,22 @@ import tabsqlitedb
 LOGGER = logging.getLogger('ibus-table')
 
 DOMAINNAME = 'ibus-table'
-_: Callable[[str], str] = lambda a: gettext.dgettext(DOMAINNAME, a)
-N_: Callable[[str], str] = lambda a: a
+
+def _(text: str) -> str:
+    '''Gettext translation function.'''
+    return gettext.dgettext(DOMAINNAME, text)
+
+def N_(text: str) -> str: # pylint: disable=invalid-name
+    '''Mark string for translation without actually translating.
+
+    Used by gettext tools to extract strings that need translation.
+    '''
+    return text
 
 # When matching keybindings, only the bits in the following mask are
 # considered for key.state:
 KEYBINDING_STATE_MASK = (
-    IBus.ModifierType.MODIFIER_MASK
+    IBus.ModifierType.MODIFIER_MASK  # pylint: disable=no-member
     & ~IBus.ModifierType.LOCK_MASK # Caps Lock
     & ~IBus.ModifierType.MOD2_MASK # Num Lock
     & ~IBus.ModifierType.MOD3_MASK # Scroll Lock
@@ -414,7 +422,7 @@ class Capabilite(Flag):
             return int(self) | other
         return NotImplemented
 
-    def __ror__(self, other: Any) -> Any: # type: ignore[override]
+    def __ror__(self, other: Any) -> Any:
         return self.__or__(other)
 
     def __and__(self, other: Any) -> Any:
@@ -426,7 +434,7 @@ class Capabilite(Flag):
             return int(self) & other
         return NotImplemented
 
-    def __rand__(self, other: Any) -> Any: # type: ignore[override]
+    def __rand__(self, other: Any) -> Any:
         return self.__and__(other)
 
     PREEDIT_TEXT = 'PREEDIT_TEXT'
@@ -628,7 +636,7 @@ class InputHints(Flag):
             return int(self) | other
         return NotImplemented
 
-    def __ror__(self, other: Any) -> Any: # type: ignore[override]
+    def __ror__(self, other: Any) -> Any:
         return self.__or__(other)
 
     def __and__(self, other: Any) -> Any:
@@ -641,7 +649,7 @@ class InputHints(Flag):
             return int(self) & other
         return NotImplemented
 
-    def __rand__(self, other: Any) -> Any: # type: ignore[override]
+    def __rand__(self, other: Any) -> Any:
         return self.__and__(other)
 
     NONE = 'NONE'
@@ -666,7 +674,7 @@ class KeyEvent:
         self.val = keyval
         self.code = keycode
         self.state = state
-        self.name = IBus.keyval_name(self.val)
+        self.name = str(IBus.keyval_name(self.val))
         if re.match(r'U\+[0-9a-fA-F]{4,5}', self.name):
             # Older versions of ibus produce
             #
@@ -706,7 +714,7 @@ class KeyEvent:
         self.button5 = self.state & IBus.ModifierType.BUTTON5_MASK != 0
         self.release = self.state & IBus.ModifierType.RELEASE_MASK != 0
         # MODIFIER_MASK: Modifier mask for the all the masks above
-        self.modifier = self.state & IBus.ModifierType.MODIFIER_MASK != 0
+        self.modifier = self.state & IBus.ModifierType.MODIFIER_MASK != 0  # pylint: disable=no-member
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, KeyEvent):
